file_streams/file_error
Types
The reasons why a file system operation could fail in Erlang. Most of these map to underlying POSIX errors.
pub type FileError {
Eacces
Eagain
Ebadf
Ebadmsg
Ebusy
Edeadlk
Edeadlock
Edquot
Eexist
Efault
Efbig
Eftype
Eintr
Einval
Eio
Eisdir
Eloop
Emfile
Emlink
Emultihop
Enametoolong
Enfile
Enobufs
Enodev
Enolck
Enolink
Enoent
Enomem
Enospc
Enosr
Enostr
Enosys
Enotblk
Enotdir
Enotsup
Enxio
Eopnotsupp
Eoverflow
Eperm
Epipe
Erange
Erofs
Espipe
Esrch
Estale
Etxtbsy
Exdev
}
Constructors
-
EaccesPermission denied.
-
EagainResource temporarily unavailable.
-
EbadfBad file number
-
EbadmsgBad message.
-
EbusyFile busy.
-
EdeadlkResource deadlock avoided.
-
EdeadlockOn most architectures, same as
Edeadlk. On some architectures, itmeans “File locking deadlock error.”
-
EdquotDisk quota exceeded.
-
EexistFile already exists.
-
EfaultBad address in system call argument.
-
EfbigFile too large.
-
EftypeInappropriate file type or format. Usually caused by trying to set the
“sticky bit” on a regular file (not a directory).
-
EintrInterrupted system call.
-
EinvalInvalid argument.
-
EioI/O error.
-
EisdirIllegal operation on a directory.
-
EloopToo many levels of symbolic links.
-
EmfileToo many open files.
-
EmlinkToo many links.
-
EmultihopMultihop attempted.
-
EnametoolongFilename too long
-
EnfileFile table overflow
-
EnobufsNo buffer space available.
-
EnodevNo such device.
-
EnolckNo locks available.
-
EnolinkLink has been severed.
-
EnoentNo such file or directory.
-
EnomemNot enough memory.
-
EnospcNo space left on device.
-
EnosrNo STREAM resources.
-
EnostrNot a STREAM.
-
EnosysFunction not implemented.
-
EnotblkBlock device required.
-
EnotdirNot a directory.
-
EnotsupOperation not supported.
-
EnxioNo such device or address.
-
EopnotsuppOperation not supported on socket.
-
EoverflowValue too large to be stored in data type.
-
EpermNot owner.
-
EpipeBroken pipe.
-
ErangeResult too large.
-
ErofsRead-only file system.
-
EspipeInvalid seek.
-
EsrchNo such process.
-
EstaleStale remote file handle.
-
EtxtbsyText file busy.
-
ExdevCross-domain link.