file_streams/read_stream_error
Types
Errors that can occur when using a read stream.
pub type ReadStreamError {
EndOfStream
OtherFileError(error: FileError)
}
Constructors
-
EndOfStreamThe end of the stream was reached before the requested data could be read.
-
OtherFileError(error: FileError)A file error occurred while reading from the stream.